﻿using System.Windows.Browser;
using System.Windows.Controls;
using Telerik.Windows.Controls.Charting;

namespace ChartIntegrationApplication
{
	public partial class Page : UserControl
	{
		public Page()
		{
			InitializeComponent();

			this.Loaded += Page_Loaded;
			
		}

		private void Page_Loaded(object sender, System.Windows.RoutedEventArgs e)
		{
			HtmlPage.RegisterScriptableObject("slChartPage", this);
		}

		/// <summary>
		/// Triggers the initialization of the control from JavaScript as we have stripped the asynchronous binding to
		/// the data service.
		/// </summary>
		[ScriptableMember]
		public void InitializeChart()
		{
			this.SetDataMappings("Custom objects");

			// RadChart works with any IEnumerable source so you can pass here your LINQ query result
			this.RadChart1.ItemsSource = RandomDataGenerator.GetObjectData();
		}

		[ScriptableMember]
        public string ChartTitle
        {
            get; 
            set;
        }

        [ScriptableMember]
        public string SeriesItemLabelFormat
        {
            get;
            set;
        }

        [ScriptableMember]
        public string AxisYLabelFormat
        {
            get;
            set;
        }

		private void SetDataMappings(string seriesLabel)
		{
			RadChart1.DefaultView.ChartLegend.Header = seriesLabel;

			SeriesMapping seriesMapping = new SeriesMapping();
			seriesMapping.SeriesDefinition = new LineSeriesDefinition();
			seriesMapping.SeriesDefinition.DefaultFormat = this.SeriesItemLabelFormat;


			ItemMapping itemMapping = new ItemMapping();
			itemMapping.DataPointMember = DataPointMember.YValue;
			itemMapping.FieldName = "DoubleData";
			seriesMapping.ItemMappings.Add(itemMapping);

			this.RadChart1.SeriesMappings.Add(seriesMapping);

			SeriesMapping seriesMapping2 = new SeriesMapping();
			seriesMapping2.SeriesDefinition = new BarSeriesDefinition();
			seriesMapping2.SeriesDefinition.DefaultFormat = this.SeriesItemLabelFormat;


			ItemMapping itemMapping2 = new ItemMapping();
			itemMapping2.DataPointMember = DataPointMember.YValue;
			itemMapping2.FieldName = "DoubleData2";
			seriesMapping2.ItemMappings.Add(itemMapping2);

			this.RadChart1.SeriesMappings.Add(seriesMapping2);

			RadChart1.DefaultView.ChartArea.AxisY.DefaultFormat = this.AxisYLabelFormat;
			RadChart1.DefaultView.ChartTitle.Content = this.ChartTitle;
		}
	}
}
